@@ -6,6 +6,7 @@ use strict;
 use warnings;
 
 use Carp;
+use POSIX qw{ uname };
 
 sub new {
     my ( $class ) = @_;
@@ -20,11 +21,26 @@ sub new {
 sub build_requires {
     my ( $self, @extra ) = @_;
     return +{
-	'Test::More'	=> 0.88,	# Because of done_testing().
+	'Test::More'	=> 0.96,	# Because of subtest().
 	@extra,
     };
 }
 
+sub ccflags {
+    my @ccflags;
+    my ( $darwin_version ) = split qr{ [.] }smx, ( uname() )[2];
+    $darwin_version >= 8
+	and push @ccflags, '-DTIGER';
+    -f '/usr/include/MacTypes.h'
+	and push @ccflags, '-DUSE_MACTYPES';
+    if ( my $debug = $ENV{DEVELOPER_DEBUG} ) {
+	push @ccflags, '-DDEBUG_PBL';
+	$debug =~ m/ \b backtrace \b /smxi
+	    and push @ccflags, '-DDEBUG_PBL_BACKTRACE';
+    }
+    return @ccflags;
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
@@ -36,6 +52,7 @@ sub requires {
 ##  }
     return {
 	'Carp'		=> 0,
+	'Encode'	=> 0,
 	'Scalar::Util'	=> 1.01,
 	'strict'	=> 0,
 	'warnings'	=> 0,
@@ -47,6 +64,66 @@ sub requires_perl {
     return 5.006;
 }
 
+sub want_pbtool {
+    my ( undef, $opt, $bldr ) = @_;	# Invocant not used
+
+    print <<"EOD";
+
+<<<< NOTICE >>>>\a\a\a
+
+In the first production release after October 1 2014, the pbtool script
+will be installed by default, and the prompt for whether or not to
+install it will be removed. If you do not want it installed, run this
+script with the -n option. The -y option will remain for compatability.
+
+EOD
+
+    if ( $opt->{n} ) {
+	$opt->{y}
+	    and die "Please do not assert both -n and -y. It is too confusing.\n";
+	print <<'EOD';
+Because you have asserted -n, the pbtool script will not be installed.
+EOD
+	return;
+
+    } elsif ( $opt->{y} ) {
+	print <<'EOD';
+Because you have asserted -y, the pbtool script will be installed.
+EOD
+	return 1;
+
+    } else {
+	print <<"EOD";
+
+The pbtool script is a front-end for Mac::Pasteboard, for ad-hoc
+manipulation of Mac OS X pasteboards.
+
+EOD
+
+	my $rslt = _prompt( $bldr,
+	    'Do you want to install pbtool?',
+	    'n',
+	);
+
+	return $rslt =~ m/ \A y /smxi;
+    }
+
+}
+
+sub _prompt {
+    my ( $bldr, @args ) = @_;
+
+    ref $bldr
+	and $bldr->can( 'prompt' )
+	and return $bldr->prompt( @args );
+
+    defined $bldr
+	or $bldr = 'main';
+    my $code = $bldr->can( 'prompt' )
+	or die "Programming error - No prompt routine available";
+    return $code->( @args );
+}
+
 
 1;
 
@@ -91,6 +168,14 @@ modules required to build the C<PPIx::Regexp> package, suitable for
 use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 
+=head2 ccflags
+
+ my @ccflags = $meta->ccflags();
+ print "cc flags - @ccflags\n";
+
+This method computes and returns the flags to be passed to the C
+compiler.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -146,7 +231,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2012 by Thomas R. Wyant, III
+Copyright (C) 2010-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
